==> vue-record-2.8.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/record/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import ActionSheet from "@dftvue2-opentiny/vue-action-sheet";
import { IconMic } from "@dftvue2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["modelValue", "isHwh5", "lockScroll"]),
  components: {
    TinyActionSheet: ActionSheet,
    IconMic: IconMic()
  },
  inheritAttrs: false,
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", [_c("tiny-action-sheet", {
    attrs: {
      "title": _vm.t("ui.record.record"),
      "visible": _vm.modelValue,
      "lock-scroll": _vm.lockScroll,
      "custom-class": "pb-0",
      "mask-closable": false
    },
    on: {
      "update:visible": function updateVisible($event) {
        return _vm.$emit("update:modelValue", $event);
      }
    },
    scopedSlots: _vm._u([{
      key: "header-left",
      fn: function fn() {
        return [_c("div", {
          staticClass: "text-base text-color-text-secondary",
          on: {
            "click": _vm.handleCancel
          }
        }, [_vm._v(" " + _vm._s(_vm.t("ui.record.cancel")) + " ")])];
      },
      proxy: true
    }, {
      key: "header-right",
      fn: function fn() {
        return [_c("div", {
          class: ["text-color-brand", ["recording", "pause"].includes(_vm.state.record.status) ? "" : "hidden"],
          on: {
            "click": _vm.handleConfirm
          }
        }, [_vm._v(" " + _vm._s(_vm.t("ui.record.confirm")) + " ")])];
      },
      proxy: true
    }, {
      key: "default",
      fn: function fn() {
        return [_c("div", {
          staticClass: "flex justify-center flex-wrap text-base text-color-text-secondary"
        }, [_c("div", {
          staticClass: "font-light",
          class: ["recording", "pause"].includes(_vm.state.record.status) ? "visible" : "invisible"
        }, [_vm._v(" " + _vm._s(_vm.state.recodeTime) + " ")]), _c("div", {
          staticClass: "relative w-full text-center px-4",
          class: ["recording"].includes(_vm.state.record.status) ? "h-24" : "h-10 my-7"
        }, [["recording"].includes(_vm.state.record.status) ? _c("canvas", {
          ref: "canvas",
          staticClass: "w-full h-full"
        }) : _c("span", {
          staticClass: "absolute left-0 bottom-0 w-full"
        }, [_vm._v(_vm._s(["ready"].includes(_vm.state.record.status) ? _vm.t("ui.record.clickToStartRecording") : _vm.t("ui.record.clickToResumeRecording")))])]), _c("div", {
          staticClass: "flex w-16 h-16 justify-center items-center mt-0 m-10 border rounded-full cursor-pointer",
          class: [["recording"].includes(_vm.state.record.status) ? "border-color-border-separator shadow-sm" : "border-color-brand"]
        }, [_c("div", {
          on: {
            "click": _vm.toogleRecord
          }
        }, [!["recording"].includes(_vm.state.record.status) ? _c("icon-mic", {
          attrs: {
            "custom-class": "w-10 h-10 fill-color-brand"
          }
        }) : _c("div", {
          staticClass: "w-6 h-6 bg-color-error rounded"
        })], 1)])])];
      },
      proxy: true
    }])
  })], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobileFirst as default
};

==> vue-record-2.22.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/record/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import ActionSheet from '@opentinyvue/vue-action-sheet';
import { IconMic } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["confirm", "error", "update:modelValue"],
  props: [].concat(props, ["modelValue", "isHwh5", "lockScroll"]),
  components: {
    TinyActionSheet: ActionSheet,
    IconMic: IconMic()
  },
  inheritAttrs: false,
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    attrs: {
      "data-tag": "tiny-record"
    }
  }, [_c("tiny-action-sheet", {
    attrs: {
      "title": _vm.t("ui.record.record"),
      "visible": _vm.modelValue,
      "lock-scroll": _vm.lockScroll,
      "custom-class": "pb-0",
      "mask-closable": false
    },
    on: {
      "update:visible": function updateVisible($event) {
        return _vm.$emit("update:modelValue", $event);
      }
    },
    scopedSlots: _vm._u([{
      key: "header-left",
      fn: function fn() {
        return [_c("div", {
          staticClass: "text-base text-color-text-secondary",
          attrs: {
            "data-tag": "tiny-record-header-left"
          },
          on: {
            "click": _vm.handleCancel
          }
        }, [_vm._v(" " + _vm._s(_vm.t("ui.record.cancel")) + " ")])];
      },
      proxy: true
    }, {
      key: "header-right",
      fn: function fn() {
        return [_c("div", {
          class: ["text-color-brand", ["recording", "pause"].includes(_vm.state.record.status) ? "" : "hidden"],
          attrs: {
            "data-tag": "tiny-record-header-right"
          },
          on: {
            "click": _vm.handleConfirm
          }
        }, [_vm._v(" " + _vm._s(_vm.t("ui.record.confirm")) + " ")])];
      },
      proxy: true
    }, {
      key: "default",
      fn: function fn() {
        return [_c("div", {
          staticClass: "flex justify-center flex-wrap text-base text-color-text-secondary",
          attrs: {
            "data-tag": "tiny-record-header-default"
          }
        }, [_c("div", {
          staticClass: "font-light",
          class: ["recording", "pause"].includes(_vm.state.record.status) ? "visible" : "invisible",
          attrs: {
            "data-tag": "tiny-record-time"
          }
        }, [_vm._v(" " + _vm._s(_vm.state.recodeTime) + " ")]), _c("div", {
          staticClass: "relative w-full text-center px-4",
          class: ["recording"].includes(_vm.state.record.status) ? "h-24" : "h-10 my-7",
          attrs: {
            "data-tag": "tiny-record-ready"
          }
        }, [["recording"].includes(_vm.state.record.status) ? _c("canvas", {
          ref: "canvas",
          staticClass: "w-full h-full"
        }) : _c("span", {
          staticClass: "absolute left-0 bottom-0 w-full"
        }, [_vm._v(_vm._s(["ready"].includes(_vm.state.record.status) ? _vm.t("ui.record.clickToStartRecording") : _vm.t("ui.record.clickToResumeRecording")))])]), _c("div", {
          staticClass: "flex w-16 h-16 justify-center items-center mt-0 m-10 border rounded-full cursor-pointer",
          class: [["recording"].includes(_vm.state.record.status) ? "border-color-border-separator shadow-sm" : "border-color-brand"],
          attrs: {
            "data-tag": "tiny-record-recording"
          }
        }, [_c("div", {
          attrs: {
            "data-tag": "tiny-record-tooglerecord"
          },
          on: {
            "click": _vm.toogleRecord
          }
        }, [!["recording"].includes(_vm.state.record.status) ? _c("icon-mic", {
          attrs: {
            "custom-class": "w-10 h-10 fill-color-brand"
          }
        }) : _c("div", {
          staticClass: "w-6 h-6 bg-color-error rounded"
        })], 1)])])];
      },
      proxy: true
    }])
  })], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
